package sun.awt.im;

import java.util.Locale;
import java.awt.Component;

public abstract class InputMethodManager
{
    private static final String threadName = "AWT-InputMethodManager";
    private static final Object LOCK;
    private static InputMethodManager inputMethodManager;
    
    public InputMethodManager() {
    }
    
    public static final InputMethodManager getInstance() {
        if (InputMethodManager.inputMethodManager != null) {
            return InputMethodManager.inputMethodManager;
        }
        synchronized (InputMethodManager.LOCK) {
            if (InputMethodManager.inputMethodManager == null) {
                ExecutableInputMethodManager executableInputMethodManager = new ExecutableInputMethodManager();
                if (executableInputMethodManager.hasMultipleInputMethods()) {
                    executableInputMethodManager.initialize();
                    Thread thread = new Thread(executableInputMethodManager, "AWT-InputMethodManager");
                    thread.setDaemon(true);
                    thread.setPriority(6);
                    thread.start();
                }
                InputMethodManager.inputMethodManager = executableInputMethodManager;
            }
        }
        return InputMethodManager.inputMethodManager;
    }
    
    public abstract String getTriggerMenuString();
    
    public abstract void notifyChangeRequest(Component p0);
    
    public abstract void notifyChangeRequestByHotKey(Component p0);
    
    abstract void setInputContext(InputContext p0);
    
    abstract InputMethodLocator findInputMethod(Locale p0);
    
    abstract Locale getDefaultKeyboardLocale();
    
    abstract boolean hasMultipleInputMethods();
    
    static {
        LOCK = new Object();
    }
}
